==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/man/map2LL.Rd <==
\name{map2LL}
\alias{map2LL}
\alias{getExten}
\alias{saveColSepData}
\alias{getOrgName}
\alias{getReverseMapping}
\alias{getUrl4Org}
\alias{getFullIDName}
\alias{saveData2Env}
\alias{reverseMap4GO}
\title{A function that maps LocusLink ids to other public repository ids
and vice versa} 
\description{
  This function uses data files provided by NCBI to create a data
  package that contains mappings between LocusLink ids and GO, RefSeq,
  and UniGene ids and vice versa 
}
\usage{
map2LL(pkgPath, organism, version, author, url =
"ftp://ftp.ncbi.nih.gov/refseq/LocusLink/")
getExten(what)
getOrgName(organism, what = c("scientific", "short"))
getReverseMapping(data, sep = ";")
getUrl4Org(organism)
getFullIDName(ID)
saveData2Env(data, fun = splitEntry, pkgName, pkgPath, envName)
reverseMap4GO(data, sep = ";")
}
\arguments{
  \item{organism}{\code{organism} a character string for the name of the
    organism of interest}
  \item{pkgPath}{\code{pkgPath} a character string for the name of the
    directory where the created data package will be stored}
  \item{version}{\code{version} a character string for the version
    number of the data package to be created}
  \item{author}{\code{author} a list with an author element for the
    name of the creater of the data package and a maintainer element for
    the email address of the creater} 
  \item{url}{\code{url} a character string for the url of NCBI's ftp
    site where source data are stored. Current value is
    \url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/}}
  \item{what}{\code{what} a character string for the type of mapping
    source data (i. e. "go", "ug" ...) or description of organism
    name("scientific" or "short")}
  \item{data}{\code{data} a matrix to be processed}
  \item{sep}{\code{sep} a character string the separator used to
    separate data elements for a given entry}
  \item{ID}{\code{ID} a character string for the short name of a data
    source (e. g. LL for LocusLink)}
  \item{envName}{\code{envName} a character string for the name of the
    environment object to be stored in the data package to be created}
  \item{fun}{\code{fun} the name of an R function to be called to
    process a data set before storing the data to an environment object}
  \item{pkgName}{\code{pkgName} a character string for the name of data
    package to be created}
}
\details{
  Three files namely loc2go, loc2ref, and loc2UG will be used to create
  the mappings. The files were in
  \url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/} at the time of the
  writing. \code{\link{getExten}} maintains names for the three
  files. Should any of the names been changed by the server,
  \code{\link{getExten}} has to be modified.

  \code{\link{getExten}} and \code{\link{saveColSepData}} are supporting
  functions to \code{\link{map2LL}} 
}
\value{
  invisible
}
\references{\url{http://www.ncbi.nlm.nih.gov/LocusLink/}}
\author{Jianhua Zhang}
\note{This function is part of Bioconductor project at Dana-Farber
  Cancer Institute to provide bioinfomatics functionalities through R}

\examples{
# Please note that the example will take a while to finish
if(interactive()){
  map2LL(pkgPath = tempdir(), version = "1.0.0", organism = "human",
author = list(author = "who", maintainer = "who@email.com"))
}
}
\keyword{manip}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/man/map2LL.Rd <==
\name{map2LL}
\alias{map2LL}
\alias{getExten}
\alias{saveColSepData}
\alias{getOrgName}
\alias{getReverseMapping}
\alias{getUrl4Org}
\alias{getFullIDName}
\alias{saveData2Env}
\alias{reverseMap4GO}
\title{A function that maps LocusLink ids to other public repository ids
and vice versa} 
\description{
  This function uses data files provided by NCBI to create a data
  package that contains mappings between LocusLink ids and GO, RefSeq,
  and UniGene ids and vice versa 
}
\usage{
map2LL(pkgPath, organism, version, author, url =
"ftp://ftp.ncbi.nih.gov/refseq/LocusLink/")
getExten(what)
getOrgName(organism, what = c("scientific", "short"))
getReverseMapping(data, sep = ";")
getUrl4Org(organism)
getFullIDName(ID)
saveData2Env(data, fun = splitEntry, pkgName, pkgPath, envName)
reverseMap4GO(data, sep = ";", type = c("ll2GO", "GO2LL")  )
}
\arguments{
  \item{organism}{\code{organism} a character string for the name of the
    organism of interest}
  \item{pkgPath}{\code{pkgPath} a character string for the name of the
    directory where the created data package will be stored}
  \item{version}{\code{version} a character string for the version
    number of the data package to be created}
  \item{author}{\code{author} a list with an author element for the
    name of the creater of the data package and a maintainer element for
    the email address of the creater} 
  \item{url}{\code{url} a character string for the url of NCBI's ftp
    site where source data are stored. Current value is
    \url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/}}
  \item{what}{\code{what} a character string for the type of mapping
    source data (i. e. "go", "ug" ...) or description of organism
    name("scientific" or "short")}
  \item{data}{\code{data} a matrix to be processed}
  \item{sep}{\code{sep} a character string the separator used to
    separate data elements for a given entry}
  \item{ID}{\code{ID} a character string for the short name of a data
    source (e. g. LL for LocusLink)}
  \item{envName}{\code{envName} a character string for the name of the
    environment object to be stored in the data package to be created}
  \item{fun}{\code{fun} the name of an R function to be called to
    process a data set before storing the data to an environment object}
  \item{pkgName}{\code{pkgName} a character string for the name of data
    package to be created}
  \item{type}{\code{what} a character string that should either be
    "ll2GO" or "GO2LL" to indicate a reverse mapping from LocusLink id
    to GO or vice versa} 
}
\details{
  Three files namely loc2go, loc2ref, and loc2UG will be used to create
  the mappings. The files were in
  \url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/} at the time of the
  writing. \code{\link{getExten}} maintains names for the three
  files. Should any of the names been changed by the server,
  \code{\link{getExten}} has to be modified.

  \code{\link{getExten}} and \code{\link{saveColSepData}} are supporting
  functions to \code{\link{map2LL}} 
}
\value{
  invisible
}
\references{\url{http://www.ncbi.nlm.nih.gov/LocusLink/}}
\author{Jianhua Zhang}
\note{This function is part of Bioconductor project at Dana-Farber
  Cancer Institute to provide bioinfomatics functionalities through R}

\examples{
# Please note that the example will take a while to finish
if(interactive()){
  map2LL(pkgPath = tempdir(), version = "1.0.0", organism = "human",
author = list(author = "myName", maintainer = "myeail@email.com"))
}
}
\keyword{manip}
